========================
Authors and contributors
========================

The following people have contributed code and/or ideas to the current version
of Neo. The institutional affiliations are those at the time of the contribution,
and may not be the current affiliation of a contributor.

* Samuel Garcia [1]
* Andrew Davison [2]
* Chris Rodgers [3]
* Pierre Yger [2]
* Yann Mahnoun [4]
* Luc Estabanez [2]
* Andrey Sobolev [5]
* Thierry Brizzi [2]
* Florent Jaillet [6]
* Philipp Rautenberg [5]
* Thomas Wachtler [5]
* Cyril Dejean [7]
* Robert Pröpper [8]
* Domenico Guarino [2]
* Achilleas Koutsou [5]
* Erik Li [9]
* Georg Raiser [10]
* Joffrey Gonin [2]
* Kyler Brown [?]
* Mikkel Elle Lepperød [11]
* C Daniel Meliza [12]
* Julia Sprenger [13]
* Maximilian Schmidt [13]
* Johanna Senk [13]
* Carlos Canova [13]
* Hélissande Fragnaud [2]
* Mark Hollenbeck [14]
* Mieszko Grodzicki
* Rick Gerkin [15]
* Matthieu Sénoville [2]
* Chadwick Boulay [16]
* Björn Müller [13]


1. Centre de Recherche en Neuroscience de Lyon, CNRS UMR5292 - INSERM U1028 - Universite Claude Bernard Lyon 1
2. Unité de Neuroscience, Information et Complexité, CNRS UPR 3293, Gif-sur-Yvette, France
3. University of California, Berkeley
4. Laboratoire de Neurosciences Intégratives et Adaptatives, CNRS UMR 6149 - Université de Provence, Marseille, France
5. G-Node, Ludwig-Maximilians-Universität, Munich, Germany
6. Institut de Neurosciences de la Timone, CNRS UMR 7289 - Université d'Aix-Marseille, Marseille, France
7. Centre de Neurosciences Integratives et Cignitives, UMR 5228 - CNRS - Université Bordeaux I - Université Bordeaux II
8. Neural Information Processing Group, TU Berlin, Germany
9. Department of Neurobiology & Anatomy, Drexel University College of Medicine, Philadelphia, PA, USA
10. University of Konstanz, Konstanz, Germany
11. Centre for Integrative Neuroplasticity (CINPLA), University of Oslo, Norway
12. University of Virginia
13. INM-6, Forschungszentrum Jülich, Germany
14. University of Texas at Austin
15. Arizona State University
16. Ottawa Hospital Research Institute, Canada


If we've somehow missed you off the list we're very sorry - please let us know.
